@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2021
+## Copyright (C) 2016-2023
 ##
 ## This file is part of the R package splines2.
 ##
@@ -137,7 +137,7 @@ bSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
         row.names(out) <- name_x
     }
     ## add class
-    class(out) <- c("matrix", "bSpline2")
+    class(out) <- c("matrix", "bSpline2", "splines2")
     ## return
     out
 }
