@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2021
+## Copyright (C) 2016-2023
 ##
 ## This file is part of the R package splines2.
 ##
@@ -125,6 +125,6 @@ iSpline <- function(x, df = NULL, knots = NULL, degree = 3L,
         row.names(out) <- name_x
     }
     ## add class
-    class(out) <- c("matrix", "iSpline")
+    class(out) <- c("matrix", "iSpline", "splines2")
     out
 }
