@@ -1,6 +1,6 @@
 ##
 ## R package splines2 by Wenjie Wang and Jun Yan
-## Copyright (C) 2016-2021
+## Copyright (C) 2016-2023
 ##
 ## This file is part of the R package splines2.
 ##
@@ -19,7 +19,7 @@
 ##'
 ##' Generates basis matrix for integrals of B-splines.
 ##'
-##' The implementation is based on the close form recursion formula.
+##' The implementation is based on the closed-form recursion formula.
 ##'
 ##' @inheritParams bSpline
 ##'
@@ -77,7 +77,7 @@ ibs <- function(x, df = NULL, knots = NULL, degree = 3,
     if (any((xx < b_knots[1L]) | (xx > b_knots[2L]))) {
         warning(wrapMessages(
             "Some 'x' values beyond boundary knots",
-            "may cause ill-conditioned bases."
+            "may cause ill-conditioned basis functions."
         ))
     }
     ## keep NA's as is
@@ -96,7 +96,7 @@ ibs <- function(x, df = NULL, knots = NULL, degree = 3,
         row.names(out) <- name_x
     }
     ## add class
-    class(out) <- c("matrix", "ibs")
+    class(out) <- c("matrix", "ibs", "splines2")
     ## return
     out
 }
